=======================================
 PyDitz -- a distributed issue tracker
=======================================

.. toctree::
   :maxdepth: 4

   readme
   doc
   faq
   api
   changes
   credits

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
